#
# spec file for package perl-Log-Any
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-Log-Any
Version:        1.040
Release:        2.5
%define cpan_name Log-Any
Summary:        Bringing loggers and listeners together
License:        Artistic-1.0 or GPL-1.0+
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/Log-Any/
Source0:        http://www.cpan.org/authors/id/D/DA/DAGOLDEN/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
%{perl_requires}

%description
'Log::Any' provides a standard log production API for modules.
Log::Any::Adapter allows applications to choose the mechanism for log
consumption, whether screen, file or another logging mechanism like
Log::Dispatch or Log::Log4perl.

Many modules have something interesting to say. Unfortunately there is no
standard way for them to say it - some output to STDERR, others to 'warn',
others to custom file logs. And there is no standard way to get a module to
start talking - sometimes you must call a uniquely named method, other
times set a package variable.

This being Perl, there are many logging mechanisms available on CPAN. Each
has their pros and cons. Unfortunately, the existence of so many mechanisms
makes it difficult for a CPAN author to commit his/her users to one of
them. This may be why many CPAN modules invent their own logging or choose
not to log at all.

To untangle this situation, we must separate the two parts of a logging
API. The first, _log production_, includes methods to output logs (like
'$log->debug') and methods to inspect whether a log level is activated
(like '$log->is_debug'). This is generally all that CPAN modules care
about. The second, _log consumption_, includes a way to configure where
logging goes (a file, the screen, etc.) and the code to send it there. This
choice generally belongs to the application.

A CPAN module uses 'Log::Any' to get a log producer object. An application,
in turn, may choose one or more logging mechanisms via Log::Any::Adapter,
or none at all.

'Log::Any' has a very tiny footprint and no dependencies beyond Perl 5.8.1,
which makes it appropriate for even small CPAN modules to use. It defaults
to 'null' logging activity, so a module can safely log without worrying
about whether the application has chosen (or will ever choose) a logging
mechanism.

See http://www.openswartz.com/2007/09/06/standard-logging-api/ for the
original post proposing this module.

%prep
%setup -q -n %{cpan_name}-%{version}

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor
%{__make} %{?_smp_mflags}

%check
%{__make} test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes CONTRIBUTING.mkdn LICENSE README

%changelog
* Tue Mar  8 2016 coolo@suse.com
- updated to 1.040
  see /usr/share/doc/packages/perl-Log-Any/Changes
  1.040     2016-02-24 17:47:00-05:00 America/New_York
    [Fixed]
  - Fixed duplicated documentation sections.
* Sat Feb 13 2016 coolo@suse.com
- updated to 1.038
  see /usr/share/doc/packages/perl-Log-Any/Changes
  1.038     2016-02-10 14:15:31-07:00 America/Mazatlan
  - No changes from 1.037
  1.037     2016-02-05 20:22:34-05:00 America/New_York (TRIAL RELEASE)
    [Fixed]
  - Fixed t/filescreen.t Unicode string tests to use a backwards
    compatible form.  Should fix tests before 5.16.
  1.035     2016-02-04 14:47:20-05:00 America/New_York (TRIAL RELEASE)
    [Changed]
  - The default formatter now replaces a code reference argument with
    the results of calling the code reference ONLY when it is the first
    argument (in place of a format string).  Code references in
    subsequent arguments (to sprintf) are not executed, as this would
    break backwards compatibility.
    [Documented]
  - Noted that repeatedly calling 'set' to set an adapter without calling
    'remove' or using the 'lexically' feature will leak memory.
  1.033     2016-02-03 10:32:57-05:00 America/New_York (TRIAL RELEASE)
    [Added]
  - The default formatter now expands code references.  If the first
    argument is a code reference, it is expanded and returned.  If an
    argument to "sprintf" style formatting is a code reference, it is
    expanded.
    [Changed]
  - The File adapter now opens files with the ":utf8" layer.  It also
    takes a 'binmode' attribute to change the default.
    [Fixed]
  - does_not_contain_ok test adapter function now gives proper
    diagnostic message
  - all diagnostic messages that output the captured log now
    correctly dump the log with pretty formatting
    [Documented]
  - documented the 'proxy_class' argument to `get_logger`
    [~Internal~]
  - Data::Dumper is loaded lazily, to reduce module load times
    for programs that don't need it.
* Tue Apr 14 2015 coolo@suse.com
- updated to 1.032
  see /usr/share/doc/packages/perl-Log-Any/Changes
  1.032     2015-03-26 17:23:37-04:00 America/New_York
  - no changes from 1.031
  1.031     2015-03-26 06:08:17-04:00 America/New_York (TRIAL RELEASE)
    [Fixed]
  - Log::Any::Adapter::Test passed through all constructor arguments,
    which could be fatal when mocking adapters without all key-value
    pairs (like Log::Any::Adapter::File); now this only passes through
    the category and ignores other parameters when used as an
    adapter class override.
  1.03      2015-01-01 22:39:41-05:00 America/New_York
    [Changed]
  - Log::Any::Proxy concatenates arguments to basic logging functions
    with a space character before passing them to adapters as a single
    string.  This ensures consistency across adapters that handle
    multiple arguments differently.
  1.02      2014-12-28 07:06:49-05:00 America/New_York
    [Fixed]
  - Some adapters relied on Log::Any::Adapter::Util also loading
    Log::Any so this behavior has been restored.
  1.01      2014-12-26 22:25:13-05:00 America/New_York
    [Fixed]
  - 'numeric_level' was not exported properly from
    Log::Any::Adapter::Util
  1.00      2014-12-25 22:04:13-05:00 America/New_York
    [Added]
  - Logging now goes via a Log::Any::Proxy object instead of directly to
    an adapter. This allows easy customization of the message production.
  - File, Stdout, and Stderr adapters now support a minimum
    log level parameter.
    [Changed]
  - Removed dead code from Log::Any::Adapter::Base; particularly this
    was the formatting code, since this is now handled by
    Log::Any::Proxy.
    [Fixed]
  - File will flock the handle when writing (if flock is avaiable).
  - Won't die if adapters aren't loadable modules as long as they
    provide a constructor.  This allows using private adapters
    defined in another file.
    [Documented]
  - Revised docs for creating adapters
  - Fixed typos and improved docs for Log::Any::Adapter::Util; removed
    stub docs for modules that didn't need it.
    [Deprecated]
  - Deprecated some methods in Log::Any::Adapter::Util
    [Internal]
  - Merged Log-Any and Log-Any-Adapter distributions; reduces code
    duplication and ensures Log::Any and adapter framework stay in sync
  - Eliminates all non-core dependencies (as of Perl 5.8.1), including
    Capture::Tiny, Devel::GlobalDestruction and Guard
  0.92      2014-12-15 07:12:38-05:00 America/New_York (TRIAL RELEASE)
  0.91      2014-12-14 22:13:09-05:00 America/New_York (TRIAL RELEASE)
  0.90      2014-12-12 17:08:22-05:00 America/New_York (TRIAL RELEASE)
* Tue Nov 26 2013 coolo@suse.com
- updated to 0.15
  * Fixes
  - Hide 'package Log::Any::Adapter' from PAUSE/Module::Metadata - miyagawa
- removed patches:
  * noprovides.diff (now upstream)
* Mon Dec 19 2011 coolo@suse.de
- update to 0.14
  * Fixes
  - Fix version number in Log/Any.pm - Stephen Thirlwal
* Tue Aug 23 2011 chris@computersalat.de
- update to 0.13
  * Fixes
  - Fix typo in lib/Log/Any/Adapter/Test.pm - RT #69850 - Stephen Thirlwall
- fix deps
  * 'ExtUtils::MakeMaker' => '6.30'
- rebase noprovides patch
* Tue May 31 2011 coolo@novell.com
- regenerate with newer cpanspec
* Thu Apr  7 2011 coolo@novell.com
- update to 0.12
  * Fixes
  - Return false from null adapter is_xxx methods - RT #64164 - Chip Salzenberg
  - Eliminate 'subroutine redefined' warning in case Log::Any::Adapter loaded before
    Log::Any::Test
  * Implementation
  - Migrate to Dist::Zilla
* Mon Jan 17 2011 coolo@novell.com
- make sure this package does not provide Log::Any::Adapter
* Tue Nov 30 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Fri Nov 19 2010 pascal.bleser@opensuse.org
- initial package (0.11)
